/*==========================================================================
*
*  Example_1 - demo application
*  by Branislav Lehotsky
*  Demonstration of using BonbliotFramework (c)
*  - is showing one DUIR component, you can setup its design interactive way (for studying of working with the DUIR)
*
*  Example_1 - demontran apka
*  Branislav Lehotsk
*  Demontruje pouitie BonbliotFramework (c)
*  - zobraz sa jedna DUIR komponenta, ktorej dizajn mono interaktvne meni (na tdium prce s DUIR)
*
*==========================================================================
*/
#include <ddraw.h>     //Direct Draw 
#include <mmsystem.h>  //koli LPWAVEFORMATEX v <dsound.h> a.i.
#include <dsound.h>    //Direct Sound

//---------------------- //hlavicka hlavnej kniznice, FrameWork by Bonbliot (c)
//#include "..\_BonbliotFramework_v3_1\DBonbliotFW.h"
#include "DBonbliotFW.h"    
//----------------------

#define IDC_BTN_1      100

#define IDC_LOOK_1     101
#define IDC_LOOK_2     102

#define IDC_AMOUNT_1   103
#define IDC_AMOUNT_2   104
#define IDC_AMOUNT_3   105

#define IDC_CONTENT_1  111
#define IDC_CONTENT_2  112

#define IDC_BACKGR_1   121
#define IDC_BACKGR_2   122
#define IDC_BACKGR_3   123

#define IDC_FONT_1     131
#define IDC_FONT_2     132
#define IDC_FONT_3     133

#define def_pi   3.14159265

bool pravedole;

//----------------------------------------------------------------
// App
//----------------------------------------------------------------
class CMyApp : public bf_CAppScreen
{
public:
  bf_CDUIR * duiR_X;
  bf_CButton * tlac_SH;

  bf_CSwitch *rb_look_1;
  bf_CSwitch *rb_look_2;
  bf_CSwitch *rb_amount_1;
  bf_CSwitch *rb_amount_2;
  bf_CSwitch *rb_amount_3;
  bf_CSwitch *rb_content_1;
  bf_CSwitch *rb_content_2;
  bf_CSwitch *rb_backgr_1;
  bf_CSwitch *rb_backgr_2;
  bf_CSwitch *rb_backgr_3;
  bf_CSwitch *rb_font_1, *rb_font_2, *rb_font_3 ;
  
  bf_CLabel *lab1, *lab2;
  bf_CDecor *dcH, *dc1, *dc2, *dc3, *dc4, *dc5;

  bf_CDas_Surface  emoticons_srf;

  CMyApp(HINSTANCE hInstance, int nCmdShow, char* cLocApp_INI);
  //~CMyApp();
  virtual void Do_LOAD_SRF();
  virtual void Do_RELEASE_SRF();
  virtual void Do_RESTORE_SRF();
  void INSERT_INTO_DUIR(int zdroj, int mnozstvo);
  virtual void Init();
  virtual int SetupVisual();
  //virtual void Init2();
  virtual void HandleWMInteraction(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam);
  virtual bool HandleFWInteraction(int iID, int ivalue, bf_CPos *p_pol = NULL);
  virtual void ChangedResolution(int maxx_old, int maxy_old, int maxx_new, int maxy_new);
  //virtual void Redraw_Screen(LPDIRECTDRAWSURFACE p_lpDDS);
  //virtual void DrawCursor(LPDIRECTDRAWSURFACE p_lpDDS);
};


//----------------------------------------------------------------
// Konstruktor
//----------------------------------------------------------------
CMyApp::CMyApp(HINSTANCE hInstance, int nCmdShow, char* cLocApp_INI) : bf_CAppScreen(hInstance, nCmdShow, cLocApp_INI)
{
   duiR_X = new bf_CDUIR(this, 200, 50);
   duiR_X->autohide = false;
   duiR_X->Rol_poc_zobr = 7;    //kolko viditelnych volieb bez rolovania

   rb_look_1 = new bf_CSwitch(this, IDC_LOOK_1);
   rb_look_2 = new bf_CSwitch(this, IDC_LOOK_2);

   rb_amount_1 = new bf_CSwitch(this, IDC_AMOUNT_1);
   rb_amount_2 = new bf_CSwitch(this, IDC_AMOUNT_2);
   rb_amount_3 = new bf_CSwitch(this, IDC_AMOUNT_3);

   rb_content_1 = new bf_CSwitch(this, IDC_CONTENT_1);
   rb_content_2 = new bf_CSwitch(this, IDC_CONTENT_2);

   rb_backgr_1 = new bf_CSwitch(this, IDC_BACKGR_1);
   rb_backgr_2 = new bf_CSwitch(this, IDC_BACKGR_2);
   rb_backgr_3 = new bf_CSwitch(this, IDC_BACKGR_3);
      
   rb_font_1 = new bf_CSwitch(this, IDC_FONT_1);
   rb_font_2 = new bf_CSwitch(this, IDC_FONT_2);
   rb_font_3 = new bf_CSwitch(this, IDC_FONT_3);

   lab1 = new bf_CLabel(this, -1);
   lab2 = new bf_CLabel(this, -1);
   dcH = new bf_CDecor(this);
   dc1 = new bf_CDecor(this);
   dc2 = new bf_CDecor(this);
   dc3 = new bf_CDecor(this);
   dc4 = new bf_CDecor(this);
   dc5 = new bf_CDecor(this);

   tlac_SH = new bf_CButton(this, IDC_BTN_1);
};

//----------------------------------------------------------------
// destruktor
//----------------------------------------------------------------
//CMyApp::~CMyApp()
//{
//};

//----------------------------------------------------------------
// nahratie SRF
//----------------------------------------------------------------
void CMyApp::Do_LOAD_SRF()
{
  emoticons_srf.LOAD_SURFACE((char*) "emoticons.bmp");
  emoticons_srf.BC_SET(0, 0);
  emoticons_srf.TC_SET(3, 3);
};

//----------------------------------------------------------------
// Uvolnit vsetky objekty surfaces
//----------------------------------------------------------------
void CMyApp::Do_RELEASE_SRF()
{
  emoticons_srf.RELEASE_SURFACE();
}

//----------------------------------------------------------------
// Restore objektov surfaces
//----------------------------------------------------------------
void CMyApp::Do_RESTORE_SRF()
{
  emoticons_srf.RESTORE_SURFACE();
}

//----------------------------------------------------------------
// Naplnenie DUIR
//   zdroj = 1 - nahlady obrazkov
//           2 - emotikony
//   mnozstvo = 0 - 7 zakladnych volieb
//              1 - 7 + rozsirenie
//              2 - dvojnasobny pocet
//----------------------------------------------------------------
void CMyApp::INSERT_INTO_DUIR( int zdroj, int mnozstvo )
{
  int pocet = 1;
  if (mnozstvo > 1) pocet = mnozstvo;

  for (int i=1; i<=pocet; i++)
  {
      if ( zdroj == 1 )
      {
        bf_Set_CIcon_default_transparency(0);

        duiR_X->ADD(1, (char*) "Picture 1 Sea",    (char*) "pict1.bmp");
        duiR_X->ADD(2, (char*) "Picture 2 Desert", (char*) "pict2.bmp");
        duiR_X->ADD(3, (char*) "Picture 3 Moon",   (char*) "pict3.bmp");
        duiR_X->ADD(4, (char*) "Picture 4 Mountains", (char*) "pict4.bmp");
        duiR_X->ADD(5, (char*) "Picture 5 Beach",  (char*) "pict5.bmp");
        duiR_X->ADD(6, (char*) "Picture 6 Lake",   (char*) "pict6.bmp");
        duiR_X->ADD(7, (char*) "Picture 7 Castle", (char*) "pict7.bmp");
        if (mnozstvo > 0 )
        {
        duiR_X->ADD(8, (char*) "Picture 8 Hotel", (char*) "pict8.bmp");
        duiR_X->ADD(9, (char*) "Picture 9 Car race", (char*) "pict9.bmp");
        }
      }
      else if (zdroj == 2)
      {
         //bf_Set_CIcon_default_transparency(1);

         duiR_X->ADD(1, (char*) "Emoticon 1", new bf_CIcon(&emoticons_srf, 30, 30), true);
         duiR_X->ADD(2, (char*) "Emoticon 2", new bf_CIcon(&emoticons_srf, 100, 30), true);
         duiR_X->ADD(3, (char*) "Emoticon 3", new bf_CIcon(&emoticons_srf, 170, 30), true);
         duiR_X->ADD(4, (char*) "Emoticon 4", new bf_CIcon(&emoticons_srf, 240, 30), true);
         duiR_X->ADD(5, (char*) "Emoticon 5", new bf_CIcon(&emoticons_srf, 30, 100), true);
         duiR_X->ADD(6, (char*) "Emoticon 6", new bf_CIcon(&emoticons_srf, 100, 100), true);
         duiR_X->ADD(7, (char*) "Emoticon 7", new bf_CIcon(&emoticons_srf, 170, 100), true);
         if (mnozstvo > 0)
         {
           duiR_X->ADD(8,  (char*) "Emoticon 8", new bf_CIcon(&emoticons_srf, 240, 100), true);
           duiR_X->ADD(9,  (char*) "Emoticon 9", new bf_CIcon(&emoticons_srf, 30, 160), true);
           duiR_X->ADD(10, (char*) "Emoticon 10", new bf_CIcon(&emoticons_srf, 100, 160), true);
           duiR_X->ADD(11, (char*) "Emoticon 11", new bf_CIcon(&emoticons_srf, 170, 160), true);
           duiR_X->ADD(12, (char*) "Emoticon 12", new bf_CIcon(&emoticons_srf, 240, 160), true);
           duiR_X->ADD(13, (char*) "Emoticon 13", new bf_CIcon(&emoticons_srf, 30, 220), true);
           duiR_X->ADD(14, (char*) "Emoticon 14", new bf_CIcon(&emoticons_srf, 100, 220), true);
           duiR_X->ADD(15, (char*) "Emoticon 15", new bf_CIcon(&emoticons_srf, 170, 220), true);
           duiR_X->ADD(16, (char*) "Emoticon 16", new bf_CIcon(&emoticons_srf, 240, 220), true);
         }
      }
  }
}

//----------------------------------------------------------------
// Init inicializacie
//----------------------------------------------------------------
void CMyApp::Init()
{
  //bf_LOG_SetONOFF(1); //zapiname log 
  INSERT_INTO_DUIR(1, 1);      //pociatocne naplnenie dui
}

//----------------------------------------------------------------
// Nastavi vizual, dizajn dialogu
//----------------------------------------------------------------
int CMyApp::SetupVisual()
{
  bf_CAppScreen::SetupVisual(); //obsluzit najprv predka (od koho je App odvodena)

  lab1->Dsgn(200, 100, (char*)"DUIR demo");
  lab1->CR_text_color = RGB(100, 180, 100);
  lab1->font_hnd = bf_DSGN_CreateFont(75, 40, FW_NORMAL, "Verdana");
  lab1->GO_TO_CENTER(bf_Get_SX(), 100);

  duiR_X->autohide = false;
  //duiR_X->font_hnd = bf_DSGN_CreateFont(15, 8, FW_BOLD, "Verdana");
  duiR_X->GO_TO_CENTER( bf_Get_SY(), bf_Get_SY() );
  
  int xx = 900; int yy = 300; int dy = 24;

  lab2->Dsgn(885, 240, (char*)"Select look of DUIR:");
  lab2->CR_text_color = RGB(255, 255, 255);
  
  rb_look_1->Dsgn(1, xx, yy);  yy += dy;
  rb_look_1->Dsgn_label(20, -1, (char*)"default", RGB(255, 255, 255));
  rb_look_2->Dsgn(1, xx, yy);  yy += dy;
  rb_look_2->Dsgn_label(20, -1, (char*)"my", RGB(255, 255, 255));
  yy += dy;
  int group = 1;
  rb_amount_1->Dsgn(1, xx, yy, group);  yy += dy;
  rb_amount_1->Dsgn_label(20, -1, (char*)"small amount", RGB(255, 255, 255));
  rb_amount_2->Dsgn(1, xx, yy, group);  yy += dy;
  rb_amount_2->Dsgn_label(20, -1, (char*)"more choices", RGB(255, 255, 255));
  rb_amount_3->Dsgn(1, xx, yy, group);  yy += dy;
  rb_amount_3->Dsgn_label(20, -1, (char*)"double the number", RGB(255, 255, 255));
  yy += dy;
  group = 2;
  rb_content_1->Dsgn(1, xx, yy, group);  yy += dy;
  rb_content_1->Dsgn_label(20, -1, (char*)"thumbnails", RGB(255, 255, 255));
  rb_content_2->Dsgn(1, xx, yy, group);  yy += dy;
  rb_content_2->Dsgn_label(20, -1, (char*)"emoticons", RGB(255, 255, 255));
  yy += dy;
  group = 3;
  rb_backgr_1->Dsgn(1, xx, yy, group);  yy += dy;
  rb_backgr_1->Dsgn_label(20, -1, (char*)"transparent background", RGB(255, 255, 255));
  rb_backgr_2->Dsgn(1, xx, yy, group);  yy += dy;
  rb_backgr_2->Dsgn_label(20, -1, (char*)"solid background", RGB(255, 255, 255));
  rb_backgr_3->Dsgn(1, xx, yy, group);  yy += dy;
  rb_backgr_3->Dsgn_label(20, -1, (char*)"no background", RGB(255, 255, 255));
  yy += dy;
  group = 4;
  rb_font_1->Dsgn(1, xx, yy, group);  xx += 80;
  rb_font_1->Dsgn_label(20, -1, (char*)"font 1", RGB(255, 255, 255));
  rb_font_2->Dsgn(1, xx, yy, group);  xx += 80;
  rb_font_2->Dsgn_label(20, -1, (char*)"font 2", RGB(255, 255, 255));
  rb_font_3->Dsgn(1, xx, yy, group);  xx += 80;
  rb_font_3->Dsgn_label(20, -1, (char*)"font 3", RGB(255, 255, 255));
  
  rb_look_1->SetCheck(true);
  rb_amount_2->SetCheck(true);
  rb_content_1->SetCheck(true);
  rb_backgr_1->SetCheck(true);
  rb_font_1->SetCheck(true);

  dcH->Dsgn(885, 255, 255, 0);
  dc1->Dsgn(885, 290, 255, 60);
  dc2->Dsgn(885, 360, 255, 86);
  dc3->Dsgn(885, 459, 255, 60);
  dc4->Dsgn(885, 529, 255, 84);
  dc5->Dsgn(885, 624, 255, 35);

  tlac_SH->Dsgn0_VoidDC(885, 672,   106, 45);   //default: void_SIR = 100; void_VYS = 45;
  tlac_SH->Dsgn_label(5, 15, (char*)"Show/Hide", RGB(100, 180, 100));

  //duiR_X->GO_TO_CENTER(bf_Get_SY(), bf_Get_SY());
  HandleFWInteraction(IDC_LOOK_1, 1, NULL);

  return 0;
}

//----------------------------------------------------------------
// Spracovanie WM 
//----------------------------------------------------------------
void CMyApp::HandleWMInteraction(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
  int mx,my;
  switch (message)
  {
  case WM_RBUTTONDOWN:      //pravy klik mysou DOWN
    mx = LOWORD(lParam);
    my = HIWORD(lParam);
    duiR_X->GO_TO_CENTER(mx, my);
    pravedole = true;
    break;

  case WM_RBUTTONUP:      //pravy klik mysou UP
    pravedole = false;
    break;

  case WM_MOUSEMOVE:
    if ( pravedole )
    {
      mx = LOWORD(lParam);
      my = HIWORD(lParam);
      duiR_X->GO_TO_CENTER(mx, my);
    }
    break;
  }
}

//----------------------------------------------------------------
// Da priestor na akciu 
//----------------------------------------------------------------
bool CMyApp::HandleFWInteraction(int iID, int ivalue, bf_CPos *p_pol)
{
  //postup cez dimenziu predkov
  bool l_b = bf_CAppScreen::HandleFWInteraction(iID, ivalue, p_pol);  //obsluzit class predka
  int ox, oy;
  int source;
  int amount;
  bool reload = false;

  switch (iID)
  {
  case IDC_BTN_1:
    duiR_X->visible = !duiR_X->visible;
    break;

  case IDC_LOOK_1:
    duiR_X->visible = true;
    duiR_X->trieda = bf_c_DUI_class_2_VERTICAL;
    //-------------
    duiR_X->RESET_DEFAULT();
    //-------------
    duiR_X->autohide = false;

   //poloha - centrovanie
    duiR_X->GO_TO_CENTER(bf_Get_SY(), bf_Get_SY());
    break;

  case IDC_LOOK_2:
    duiR_X->visible = true;
    duiR_X->trieda = bf_c_DUI_class_2_VERTICAL;
    duiR_X->autohide = false;
    
    //konstanty a, b, c, d
    //duiR_X->Set_Constants(52, 60, 200, 20);
    duiR_X->Compute_stats();
    duiR_X->Set_Constants(52, //max(duiR_X->max_text_vys,duiR_X->max_icon_vys),
            60,
            duiR_X->max_text_sir + duiR_X->max_icon_sir + 6,
            20);

    //nastavit default mody a padding-y
    duiR_X->SetTextMode((char*)"LC" );  //LeftCenter, padding=1
    duiR_X->TextPadding = 1;
    duiR_X->SetIconMode((char*)"RC" );  //RightCenter, padding=1
    duiR_X->IconPadding = 1;

    //poloha - centrovanie na stred okna
    duiR_X->GO_TO_CENTER(bf_Get_SY(), bf_Get_SY());
    break;

  case IDC_AMOUNT_1:  //small amount
  case IDC_AMOUNT_2:  //more
  case IDC_AMOUNT_3:  //double
    reload = true;
    break;

  case IDC_CONTENT_1:  //thumb.
  case IDC_CONTENT_2:  //emoticions
    reload = true;
    break;
    
  case IDC_BACKGR_1:
    duiR_X->backgr_typ = 1;  //priesvitne sito
    break;
  case IDC_BACKGR_2:
    duiR_X->backgr_typ = 2;  //plne
    break;
  case IDC_BACKGR_3:
    duiR_X->backgr_typ = 0;  //bez
    break;

  case IDC_FONT_1:
    duiR_X->SetFont(15, 9, FW_NORMAL, "Verdana");   //len font DUI
    //bf_DSGN_SetLabelsDefaultFont(15, 9, FW_NORMAL, "Verdana");  //vseobecne font pre lable
    break;
  case IDC_FONT_2:
    duiR_X->SetFont(15, 8, FW_NORMAL, "Verdana");
    //bf_DSGN_SetLabelsDefaultFont(15, 8, FW_NORMAL, "Verdana");
    break;
  case IDC_FONT_3:
    duiR_X->SetFont(15, 8, FW_BOLD, "Verdana");
    //bf_DSGN_SetLabelsDefaultFont(15, 8, FW_BOLD, "Verdana");
    break;
  }

  if (reload)
  { 
    //parametre obsahu
    if (rb_amount_1->GetCheck()) amount = 0;
    if (rb_amount_2->GetCheck()) amount = 1;
    if (rb_amount_3->GetCheck()) amount = 2;
    if (rb_content_1->GetCheck()) source = 1;
    if (rb_content_2->GetCheck()) source = 2;

    //renaplnit
    duiR_X->DELETE_ALL();
    INSERT_INTO_DUIR(source, amount);

    //rekalkulovat
    if (rb_look_1->GetCheck()) HandleFWInteraction(IDC_LOOK_1, 1, NULL);
    if (rb_look_2->GetCheck()) HandleFWInteraction(IDC_LOOK_2, 1, NULL);
  }
  
  return l_b;
}

//----------------------------------------------------------------
// Volane po zmene rozmerov obrazovky
//----------------------------------------------------------------
void CMyApp::ChangedResolution(int maxx_old, int maxy_old, int maxx_new, int maxy_new)
{
  //postup cez dimenziu predkov (vratit funkcnost predkovi, lebo cez virtual bola obidena, prepisana)
  bf_CAppScreen::ChangedResolution(maxx_old, maxy_old, maxx_new, maxy_new);  //obsluzit class predka

  //popisku centrovat
  lab1->GO_TO_CENTER(bf_Get_SX(), 100);

  //renaplnit
  if (rb_content_1->GetCheck()) HandleFWInteraction(IDC_CONTENT_1, 1, NULL);
  if (rb_content_2->GetCheck()) HandleFWInteraction(IDC_CONTENT_2, 1, NULL);
}

/*
//----------------------------------------------------------------
// Prekreslit celu scenu 
//----------------------------------------------------------------
void CMyApp::Redraw_Screen(LPDIRECTDRAWSURFACE p_lpDDS)
{
  //<--- vymazat
  //DDSURFACE_ZMAZ(p_lpDDS, 500);
  //emoticons_srf.ZOBRAZ(5, 5);
}
*/
/*
//----------------------------------------------------------------
// Vykreslit kurzor
//----------------------------------------------------------------
void CMyApp::DrawCursor(LPDIRECTDRAWSURFACE p_lpDDS)
{
}
*/

//==============================================================================

//----------------------------------------------------------------
// Vstupny bod pre Appku
//----------------------------------------------------------------
int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
  LPSTR lpCmdLine, int nCmdShow)
{
  //bf_Set_Lang(bf_c_Lang_EN);
  CMyApp *pAPP = new CMyApp(hInstance, nCmdShow, (char*) "EXAMPLE.INI");    //vytvorit instanciu
  pAPP->SetBackground(500, (char*)"", false);   //tmavomodra farba pozadia, ziaden obraz ako podklad, ziadne logo
  pAPP->SetAppInfo((char*)"Example, DUIR demo", (char*)"(version: 1.0)", (char*)"Branislav Lehotsk");  //info polia
  pAPP->SetLang( bf_c_Lang_EN );   // bf_c_Lang_EN / bf_c_Lang_SK 
  pAPP->Execute();  //spustit
  delete pAPP;
  return 0;
}
